/*!
 * Ext JS Library 3.3.1
 * Copyright(c) 2006-2010 Sencha Inc.
 * licensing@sencha.com
 * http://www.sencha.com/license
 */
/**
 * @class Ext.calendar.EventEditWindow
 * @extends Ext.Window
 * <p>A custom window containing a basic edit form used for quick editing of events.</p>
 * <p>This window also provides custom events specific to the calendar so that other calendar components can be easily
 * notified when an event has been edited via this component.</p>
 * @constructor
 * @param {Object} config The config object
 */

var calendarCategoryWin = function(name){	
	isLoaded=false;
	var winName = name+'-Win';
	if(Ext.getCmp(winName)){
		Ext.getCmp(winName).close(true);
	}
	var categoryGridStore = new Ext.data.Store({
		proxy: new Ext.data.HttpProxy({
			url: '/service/issueManager_proc.php?method=getCalendarCategoryList'
		}),
		reader: new Ext.data.JsonReader({fields : ['id','title','color'],root:'data'})
		,autoLoad : true
	});	

	var categoryGridsm = new Ext.grid.CheckboxSelectionModel({ singleSelect: true });
	var categoryGridPanel = new Ext.grid.EditorGridPanel({
		id:'categoryGridPanel',	
		store: categoryGridStore,
		border:false,
		autoScroll: true,
		stripeRows: true,
		clicksToEdit: 1,
		enableColumnHide  : false,
		enableColumnResize: true,
		enableColumnMove  : false,
		enableHdMenu: false,
		loadMask: { msg: 'Loding...' },
		view: new Ext.grid.GridView({
			forceFit:true
		}),
		cm : new Ext.grid.ColumnModel([
			categoryGridsm,
			{header: 'Seq', dataIndex: 'id', align:'center', sortable: true, width: 100, tooltip: 'seq' },
			{header: 'Title', dataIndex: 'title', align:'left', sortable: true, width: 300, 
				editor: new Ext.form.TextField({
                    allowBlank: false
			})},//ColorPalette
			{header: 'Color', dataIndex: 'color', align:'center', sortable: true, width: 300}
		]),
		sm: categoryGridsm,
		listeners: {
			rowclick:function(grid, rowIndex, e) {},
			rowdblclick: function(grid){}
		}
	});
		/*var centerPanel = {
			region: 'center',		
			id:'memberGroup-center',
			layout: 'fit',				
			items: [categoryGridPanel]
		};*/

		var calendarWindowMenu = new Ext.menu.Menu({
			cls: 'x-calendar-list-menu',
			items: [new Ext.ColorPalette({
				handler: function(palette, colorId) {
					var record = calendarPanel.calendarStore.getAt(calendarWindowMenu.recordIndex);
					record.set('id', colorId);
					calendarWindowMenu.hide();
					calendarWindowDataView.refreshNode(calendarWindowMenu.recordIndex);
				}
			})]
		});
			
		var centerPanel = {
			region: 'center',		
			id:'memberGroup-center',
			layout: 'fit',				
			items: [new Ext.DataView({
				store: categoryGridStore,
				cls: 'x-combo-list',
				style: 'background-color: white; padding: 5px',
				itemSelector: '.x-combo-list-item',
				selectedClass: 'x-combo-selected',
				overClass: 'x-combo-selected',
				autoScroll: true,
				tpl: new Ext.XTemplate(
					'<tpl for=".">',
						'<div class="x-combo-list-item" style="vertical-align: middle">',
							'<div class="x-cal-{id}">',
								'<div class="mail-calendar-cat-color ext-cal-picker-icon" onmouseover="Ext.get(this).addClass(\'mail-calendar-cat-color-over\');" onmouseout="Ext.get(this).removeClass(\'mail-calendar-cat-color-over\');">&nbsp;</div>',
							'</div>',
							'<div>{title}</div>',
						'</div>',
					'</tpl>',
					'<div class="x-clear"></div>'
				)				
			})]
		};

		var updateItemWin = new Ext.Window({
			title: name,
			id: name+'-Win',
			modal:true,
			width:500,
			height:450,
			border:false,
			layout: 'border',
			resizable: false, //Resize of the Window, if false - it cannot be resized
			closable: false,
			items: [centerPanel],
			tbar:[{
				xtype:'button',
				text:'Add',
				id:'memberAddBtn',
				autoExpandColumn: 'name',
				clicksToEdit: 1,
				handler: function(btn) {				
					var Plant = memberGridPanel.getStore().recordType;
					var p = new Plant({
						seq: '',
						name: 'New Name',//Date.parseDate(value, "Y-m-d").format('Y-m-d');
						regdate: new Date(),
						area: 1
					});
					memberGridPanel.stopEditing();
					memberStore.insert(0, p);
					memberGridPanel.startEditing(0, 2);
				}
			},'->', {
				xtype: 'button',
				id:name+'-save',
				iconCls: 'icon-save',
				text: TPMS_lang_button_save,
				handler: function(btn) {
					var changeRecords = memberStore.getModifiedRecords();
					var isAction = false;
					var newObj=new Array();
					alert(changeRecords.length);
												
					for(var i=0;i<changeRecords.length;i++){
						var name = changeRecords[i].data.name.trim();
						if(!name){
							Ext.Msg.alert("Error","̸ Էϼ");
							return;
						}
						isAction = true;
						var seq='';
						if(changeRecords[i].data.seq){
							seq = changeRecords[i].data.seq.trim();
						}
						newObj.push({tmpSeq:seq,tmpName:changeRecords[i].data.name.trim(),tmpRegdate:changeRecords[i].data.regdate,tmpArea:changeRecords[i].data.area});
					}
					
					if(isAction){
						Ext.Ajax.request({
							scope : this,
							url: './index5_proc.php?method=update',
							method : 'POST',
							params :{ 
								data : Ext.encode(newObj)
							},
							success: function ( result, request ) {							
								if(result.responseText){								
									memberStore.reload();
									memberStore.rejectChanges();
								}
							},
							failure: function ( result, request ) {}
						});
					}
				}
		},'-',{
			xtype: 'button',
			iconCls: 'icon-cancel',
			text: TPMS_lang_button_cancel,
			handler: function() {
				updateItemWin.close();
				isLoaded=false;
			}
		}]
	});	
	updateItemWin.show(this);
};

Ext.calendar.EventEditWindow = function(config) {
    var formPanelCfg = {
        xtype: 'form',
        labelWidth: 65,
        frame: false,
        bodyStyle: 'background:transparent;padding:5px 10px 10px;',
        bodyBorder: false,
        border: false,
        items: [{
            id: 'title',
            name: Ext.calendar.EventMappings.Title.name,
            fieldLabel: 'Title',
            xtype: 'textfield',
            anchor: '100%'
        },
        {
            xtype: 'daterangefield',
            id: 'date-range',//date-range
            anchor: '100%',
            fieldLabel: 'When'
        }]
    };

    if (config.calendarStore) {
        this.calendarStore = config.calendarStore;
        delete config.calendarStore;

        formPanelCfg.items.push({
            /*xtype:'combo',			
			id:'calendar',
			anchor: '100%',
			name: 'calendar',
			store: this.calendarStore,
			valueField:'CalendarId', 
			displayField:'Title',
			mode: 'local',
			typeAhead     : false,
			editable      : false,
			forceSelection: false,
			selectOnFocus : false,
			triggerAction : 'all'*/

			xtype: 'calendarpicker',
            id: 'calendar',
            name: 'calendar',
            anchor: '100%',			
            //store: this.calendarStore,
			store: sampleStore,
			mode: 'local',
			typeAhead     : false,
			editable      : false,
			forceSelection: false,
			selectOnFocus : false,
			triggerAction : 'all'
        });
    }
	/*formPanelCfg.items.push({
		xtype:'button',
		fieldLabel : 'Category',
		text:'Add Category',
		handler : function(btn){
			calendarCategoryWin("CategoryWin");			
		}
	});*/

    Ext.calendar.EventEditWindow.superclass.constructor.call(this, Ext.apply({
        titleTextAdd: 'Add Event',
        titleTextEdit: 'Edit Event',
        width: 600,
        autocreate: true,
        border: true,
        closeAction: 'hide',
        modal: false,
        resizable: false,
        buttonAlign: 'left',
        savingMessage: 'Saving changes...',
        deletingMessage: 'Deleting event...',

        fbar: [/*{
            xtype: 'tbtext',
            text: '<a href="#" id="tblink">Edit Details...</a>'
        },*/
        '->', {
            text: 'Save',
            disabled: false,
            handler: this.onSave,
            scope: this
        },
        {
            id: 'delete-btn',
            text: 'Delete',
            disabled: false,
            handler: this.onDelete,
            scope: this,
            hideMode: 'offsets'
        },
        {
            text: 'Cancel',
            disabled: false,
            handler: this.onCancel,
            scope: this
        }],
        items: formPanelCfg
    },
    config));
};

Ext.extend(Ext.calendar.EventEditWindow, Ext.Window, {
    // private
    newId: 10000,

    // private
    initComponent: function() {
        Ext.calendar.EventEditWindow.superclass.initComponent.call(this);

        this.formPanel = this.items.items[0];

        this.addEvents({
            /**
             * @event eventadd
             * Fires after a new event is added
             * @param {Ext.calendar.EventEditWindow} this
             * @param {Ext.calendar.EventRecord} rec The new {@link Ext.calendar.EventRecord record} that was added
             */
            eventadd: true,
            /**
             * @event eventupdate
             * Fires after an existing event is updated
             * @param {Ext.calendar.EventEditWindow} this
             * @param {Ext.calendar.EventRecord} rec The new {@link Ext.calendar.EventRecord record} that was updated
             */
            eventupdate: true,
            /**
             * @event eventdelete
             * Fires after an event is deleted
             * @param {Ext.calendar.EventEditWindow} this
             * @param {Ext.calendar.EventRecord} rec The new {@link Ext.calendar.EventRecord record} that was deleted
             */
            eventdelete: true,
            /**
             * @event eventcancel
             * Fires after an event add/edit operation is canceled by the user and no store update took place
             * @param {Ext.calendar.EventEditWindow} this
             * @param {Ext.calendar.EventRecord} rec The new {@link Ext.calendar.EventRecord record} that was canceled
             */
            eventcancel: true,
            /**
             * @event editdetails
             * Fires when the user selects the option in this window to continue editing in the detailed edit form
             * (by default, an instance of {@link Ext.calendar.EventEditForm}. Handling code should hide this window
             * and transfer the current event record to the appropriate instance of the detailed form by showing it
             * and calling {@link Ext.calendar.EventEditForm#loadRecord loadRecord}.
             * @param {Ext.calendar.EventEditWindow} this
             * @param {Ext.calendar.EventRecord} rec The {@link Ext.calendar.EventRecord record} that is currently being edited
             */
            editdetails: true
        });
    },

    // private
    afterRender: function() {
        Ext.calendar.EventEditWindow.superclass.afterRender.call(this);

        this.el.addClass('ext-cal-event-win');

        /*Ext.get('tblink').on('click',
			function(e) {				
				//e.stopEvent();
				//this.updateRecord();
				//this.fireEvent('editdetails', this, this.activeRecord);
			},
        this);*/
    },

    /**
     * Shows the window, rendering it first if necessary, or activates it and brings it to front if hidden.
	 * @param {Ext.data.Record/Object} o Either a {@link Ext.data.Record} if showing the form
	 * for an existing event in edit mode, or a plain object containing a StartDate property (and 
	 * optionally an EndDate property) for showing the form in add mode. 
     * @param {String/Element} animateTarget (optional) The target element or id from which the window should
     * animate while opening (defaults to null with no animation)
     * @return {Ext.Window} this
     */
    show: function(o, animateTarget) {
        // Work around the CSS day cell height hack needed for initial render in IE8/strict:
        var anim = (Ext.isIE8 && Ext.isStrict) ? null: animateTarget;

        Ext.calendar.EventEditWindow.superclass.show.call(this, anim,
        function() {
            Ext.getCmp('title').focus(false, 100);
        });
        Ext.getCmp('delete-btn')[o.data && o.data[Ext.calendar.EventMappings.EventId.name] ? 'show': 'hide']();

        var rec,
        f = this.formPanel.form;

        if (o.data) {
            rec = o;
            this.isAdd = !!rec.data[Ext.calendar.EventMappings.IsNew.name];
            if (this.isAdd) {
                // Enable adding the default record that was passed in
                // if it's new even if the user makes no changes
                rec.markDirty();
                this.setTitle(this.titleTextAdd);
            }
            else {
                this.setTitle(this.titleTextEdit);
            }

            f.loadRecord(rec);
        }
        else {
            this.isAdd = true;
            this.setTitle(this.titleTextAdd);

            var M = Ext.calendar.EventMappings,
            eventId = M.EventId.name,
            start = o[M.StartDate.name],
            end = o[M.EndDate.name] || start.add('h', 1);
			

            rec = new Ext.calendar.EventRecord();
            rec.data[M.EventId.name] = this.newId++;
            rec.data[M.StartDate.name] = start;
            rec.data[M.EndDate.name] = end;
            rec.data[M.IsAllDay.name] = !!o[M.IsAllDay.name] || start.getDate() != end.clone().add(Date.MILLI, 1).getDate();
            rec.data[M.IsNew.name] = true;

			f.reset();
            f.loadRecord(rec);
        }

        if (this.calendarStore) {
            Ext.getCmp('calendar').setValue(rec.data[Ext.calendar.EventMappings.CalendarId.name]);
        }
        Ext.getCmp('date-range').setValue(rec.data);
        this.activeRecord = rec;

        return this;
    },

    // private
    roundTime: function(dt, incr) {
        incr = incr || 15;
        var m = parseInt(dt.getMinutes(), 10);
        return dt.add('mi', incr - (m % incr));
    },

    // private
    onCancel: function() {
        this.cleanup(true);
        this.fireEvent('eventcancel', this);
    },

    // private
    cleanup: function(hide) {
        if (this.activeRecord && this.activeRecord.dirty) {
            this.activeRecord.reject();
        }
        delete this.activeRecord;

        if (hide === true) {
            // Work around the CSS day cell height hack needed for initial render in IE8/strict:
            //var anim = afterDelete || (Ext.isIE8 && Ext.isStrict) ? null : this.animateTarget;
            this.hide();
        }
    },

    // private
    updateRecord: function() {
        var f = this.formPanel.form,
        dates = Ext.getCmp('date-range').getValue(),
        M = Ext.calendar.EventMappings;

        f.updateRecord(this.activeRecord);
        this.activeRecord.set(M.StartDate.name, dates[0]);
        this.activeRecord.set(M.EndDate.name, dates[1]);
        this.activeRecord.set(M.IsAllDay.name, dates[2]);
        this.activeRecord.set(M.CalendarId.name, this.formPanel.form.findField('calendar').getValue());
    },

    // private
    onSave: function() {
        if (!this.formPanel.form.isValid()) {
            return;
        }
        this.updateRecord();

        if (!this.activeRecord.dirty) {
            this.onCancel();
            return;
        }

        this.fireEvent(this.isAdd ? 'eventadd': 'eventupdate', this, this.activeRecord);
    },

    // private
    onDelete: function() {
        this.fireEvent('eventdelete', this, this.activeRecord);
    }
});